package snake.grafica;
import java.awt.Color;
import java.awt.Graphics;
import java.awt.event.KeyEvent;
import java.awt.event.KeyListener;

import javax.swing.JPanel;

import snake.config.Impostazioni;
import snake.core.Blocco;
import snake.core.Erba;
import snake.core.GestoreMovimento;
import snake.core.Serpente;
import snake.core.Snake;

public class PannelloSnake extends JPanel implements KeyListener {
	
	Snake snake;
	
	public PannelloSnake(Snake s) {
		this.snake = s;
	}
	
	private void disegnaErba(Graphics g) {
		Color orig = g.getColor();
		g.setColor(Color.GREEN);
		for(Erba e : snake.getErba()) {
			g.fillRect(e.getX(), e.getY(), Impostazioni.DIMENSIONE_BLOCCO, Impostazioni.DIMENSIONE_BLOCCO);			
		}
		g.setColor(orig);
	}
	
	@Override
	protected void paintComponent(Graphics g) {		
		super.paintComponent(g);
		this.setBackground(Color.WHITE);
		disegnaErba(g);
		
		Blocco b = snake.getBlocco();
			
		g.setColor(Color.BLUE);
		g.fillRect(b.getX(), b.getY(), Impostazioni.DIMENSIONE_BLOCCO, Impostazioni.DIMENSIONE_BLOCCO);
		g.setColor(Color.BLACK);
		
		Serpente ser = snake.getSerpente();		
		g.fillOval(ser.getTesta().getX(), ser.getTesta().getY(), Impostazioni.DIMENSIONE_BLOCCO, Impostazioni.DIMENSIONE_BLOCCO);		
		for(Blocco c : ser.getCorpo())
			g.fillRect(c.getX(), c.getY(), Impostazioni.DIMENSIONE_BLOCCO, Impostazioni.DIMENSIONE_BLOCCO);
		
		if(!snake.isVivo())
			g.drawString("Hai perso! Premi n per iniziare una nuova partita", Impostazioni.DIMENSIONE_FINESTRA/8, Impostazioni.DIMENSIONE_FINESTRA/2);
	}

	@Override
	public void keyTyped(KeyEvent e) {}

	@Override
	public void keyPressed(KeyEvent e) {
		if(snake.isVivo()) {
			switch(e.getKeyCode()) {
			case KeyEvent.VK_LEFT:
				snake.muovi(GestoreMovimento.MUOVI_SINISTRA);
				break;
			case KeyEvent.VK_RIGHT:
				snake.muovi(GestoreMovimento.MUOVI_DESTRA);
				break;
			case KeyEvent.VK_DOWN:
				snake.muovi(GestoreMovimento.MUOVI_SOTTO);
				break;
			case KeyEvent.VK_UP:
				snake.muovi(GestoreMovimento.MUOVI_SOPRA);
				break;
			default:
				break;
			}		
			repaint();
		}
		else {
			switch(e.getKeyCode()) {
			case KeyEvent.VK_N:
				snake = new Snake();
				repaint();
			}
		}
	}		

	@Override
	public void keyReleased(KeyEvent e) {}
}
